@@ -1,8 +1,15 @@
 # @CODE:CORE-PROJECT-001 | SPEC: SPEC-CORE-PROJECT-001.md | TEST: tests/unit/test_language_detector.py
 # @CODE:LANG-DETECT-001 | SPEC: SPEC-LANG-DETECT-001.md | TEST: tests/unit/test_detector.py
+# @CODE:LDE-EXTENDED-001 | SPEC: SPEC-LANGUAGE-DETECTION-EXTENDED-001/spec.md | TEST: tests/unit/test_language_detector_extended.py
 """Language detector module.
 
 Automatically detects 20 programming languages.
+
+Extended detection supports:
+- 11 new languages: Ruby, PHP, Java, Rust, Dart, Swift, Kotlin, C#, C, C++, Shell
+- 5 build tool detection: Maven, Gradle, CMake, SPM, dotnet
+- Package manager detection: bundle, composer, cargo
+- Priority conflict resolution for multi-language projects
 """
 
 from pathlib import Path
@@ -118,107 +125,6 @@ class LanguageDetector:
 
         return False
 
-    # @CODE:LANG-002 | SPEC: SPEC-LANGUAGE-DETECTION-001.md | TEST: tests/unit/test_detector.py
-    def detect_package_manager(self, path: str | Path = ".") -> str:
-        """Detect JavaScript/TypeScript package manager.
-
-        Checks for lock files in priority order (highest to lowest):
-        1. bun.lockb (Bun) - fastest runtime
-        2. pnpm-lock.yaml (pnpm) - efficient disk usage
-        3. yarn.lock (Yarn) - Facebook's package manager
-        4. package-lock.json (npm) - default Node.js package manager
-
-        Priority order reflects modern best practices and performance characteristics.
-
-        Args:
-            path: Project root directory to inspect. Defaults to current directory.
-
-        Returns:
-            Package manager name: 'bun' | 'pnpm' | 'yarn' | 'npm'
-
-        Example:
-            >>> detector = LanguageDetector()
-            >>> detector.detect_package_manager("/path/to/project")
-            'pnpm'
-        """
-        path = Path(path)
-
-        # Check in priority order (Bun → pnpm → Yarn → npm)
-        if (path / "bun.lockb").exists():
-            return "bun"
-        elif (path / "pnpm-lock.yaml").exists():
-            return "pnpm"
-        elif (path / "yarn.lock").exists():
-            return "yarn"
-        else:
-            # Default to npm (most common, works everywhere)
-            return "npm"
-
-    # @CODE:LANG-002 | SPEC: SPEC-LANGUAGE-DETECTION-001.md | TEST: tests/unit/test_detector.py
-    def get_workflow_template_path(self, language: str) -> str:
-        """Get workflow template path for detected language.
-
-        Returns the relative path to the language-specific GitHub Actions workflow template.
-        These templates are pre-configured with language-specific testing tools, linting,
-        and coverage reporting.
-
-        Args:
-            language: Detected language name (lowercase).
-                      Supported: 'python', 'javascript', 'typescript', 'go'
-
-        Returns:
-            Relative path to workflow template (e.g., 'workflows/python-tag-validation.yml')
-
-        Raises:
-            ValueError: If language doesn't have a dedicated workflow template
-
-        Example:
-            >>> detector = LanguageDetector()
-            >>> detector.get_workflow_template_path("python")
-            'workflows/python-tag-validation.yml'
-        """
-        # Language-to-template mapping (add new languages here)
-        template_mapping = {
-            "python": "python-tag-validation.yml",
-            "javascript": "javascript-tag-validation.yml",
-            "typescript": "typescript-tag-validation.yml",
-            "go": "go-tag-validation.yml",
-        }
-
-        if language not in template_mapping:
-            supported = ", ".join(sorted(template_mapping.keys()))
-            raise ValueError(
-                f"Language '{language}' does not have a dedicated workflow template. "
-                f"Supported languages: {supported}"
-            )
-
-        template_filename = template_mapping[language]
-        # Return path relative to templates directory
-        return f"workflows/{template_filename}"
-
-    # @CODE:LANG-002 | SPEC: SPEC-LANGUAGE-DETECTION-001.md | TEST: tests/unit/test_detector.py
-    def get_supported_languages_for_workflows(self) -> list[str]:
-        """Get list of languages with dedicated workflow templates.
-
-        Returns languages that have pre-built GitHub Actions workflow templates
-        with language-specific testing, linting, and coverage configuration.
-
-        Returns:
-            List of supported language names (lowercase)
-
-        Example:
-            >>> detector = LanguageDetector()
-            >>> detector.get_supported_languages_for_workflows()
-            ['python', 'javascript', 'typescript', 'go']
-
-        Note:
-            While LanguageDetector can detect 20+ languages, only these 4
-            have dedicated CI/CD workflow templates. Other languages fall back
-            to generic workflows.
-        """
-        return ["python", "javascript", "typescript", "go"]
-
-
     def get_workflow_template_path(self, language: str) -> str:
         """Get the GitHub Actions workflow template path for a language.
 
@@ -253,7 +159,7 @@ class LanguageDetector:
 
         if language.lower() not in workflow_mapping:
             raise ValueError(
-                f"No workflow template available for language: {language}. "
+                f"Unsupported language: {language}. "
                 f"Supported languages: {', '.join(workflow_mapping.keys())}"
             )
 
@@ -306,8 +212,18 @@ class LanguageDetector:
         if (path / "pyproject.toml").exists():
             return "pip"
 
-        # JavaScript/TypeScript
-        if (path / "package.json").exists():
+        # JavaScript/TypeScript (check in priority order)
+        # Check for lock files and package managers
+        if (path / "bun.lockb").exists():
+            return "bun"
+        elif (path / "pnpm-lock.yaml").exists():
+            return "pnpm"
+        elif (path / "yarn.lock").exists():
+            return "yarn"
+        elif (path / "package-lock.json").exists():
+            return "npm"
+        elif (path / "package.json").exists():
+            # Default to npm for package.json without lock files
             return "npm"
 
         # Go
