@@ -1,4 +1,5 @@
 # @CODE:INIT-003:PHASE | SPEC: .moai/specs/SPEC-INIT-003/spec.md | TEST: tests/unit/test_init_reinit.py
+# @CODE:TEST-COVERAGE-001 | SPEC: SPEC-TEST-COVERAGE-001.md | TEST: tests/unit/test_phase_executor.py
 """Phase-based installation executor (SPEC-INIT-003 v0.4.2)
 
 Runs the project initialization across five phases:
@@ -7,9 +8,12 @@ Runs the project initialization across five phases:
 - Phase 3: Resource (copy templates while preserving user content)
 - Phase 4: Configuration (generate configuration files)
 - Phase 5: Validation (verify and finalize)
+
+Test coverage includes 5-phase integration tests with backup, configuration, and validation
 """
 
 import json
+import platform
 import shutil
 import subprocess
 from collections.abc import Callable
@@ -142,10 +146,16 @@ class PhaseExecutor:
         # Set template variable context (if provided)
         if config:
             # @TAG:LANG-FIX-001:PY-CONFIG | Read language from nested config structure
-            language_config = config.get("language", {})
+            language_config: dict[str, Any] = config.get("language", {})
             if not isinstance(language_config, dict):
                 language_config = {}
 
+            # Detect OS for cross-platform Hook path configuration
+            hook_project_dir = (
+                "%CLAUDE_PROJECT_DIR%" if platform.system() == "Windows"
+                else "$CLAUDE_PROJECT_DIR"
+            )
+
             context = {
                 "MOAI_VERSION": __version__,
                 "CREATION_TIMESTAMP": datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
@@ -158,6 +168,7 @@ class PhaseExecutor:
                 "CONVERSATION_LANGUAGE": language_config.get("conversation_language", "en"),
                 "CONVERSATION_LANGUAGE_NAME": language_config.get("conversation_language_name", "English"),
                 "CODEBASE_LANGUAGE": config.get("language", "generic"),
+                "HOOK_PROJECT_DIR": hook_project_dir,
             }
             processor.set_context(context)
 
@@ -193,6 +204,43 @@ class PhaseExecutor:
             "Phase 4: Generating configurations...", progress_callback
         )
 
+        # Read existing config to preserve user settings (Issue #165)
+        config_path = project_path / ".moai" / "config.json"
+        existing_config: dict[str, Any] = {}
+        if config_path.exists():
+            try:
+                with open(config_path, "r", encoding="utf-8") as f:
+                    existing_config = json.load(f)
+            except (json.JSONDecodeError, OSError):
+                # If config reading fails, start fresh
+                existing_config = {}
+
+        # Merge user settings from existing config (preserve customization)
+        if existing_config:
+            # Preserve user.nickname if it exists
+            if "user" in existing_config and isinstance(existing_config.get("user"), dict):
+                if "user" not in config:
+                    config["user"] = {}
+                user_config = config["user"]
+                if isinstance(user_config, dict):
+                    existing_user = existing_config["user"]
+                    if isinstance(existing_user, dict) and "nickname" in existing_user:
+                        user_config["nickname"] = existing_user["nickname"]
+
+            # Preserve language settings if they exist
+            if "language" in existing_config and isinstance(existing_config.get("language"), dict):
+                if "language" not in config:
+                    config["language"] = {}
+                lang_config = config["language"]
+                if isinstance(lang_config, dict):
+                    existing_lang = existing_config["language"]
+                    if isinstance(existing_lang, dict):
+                        # Preserve conversation_language settings
+                        if "conversation_language" in existing_lang:
+                            lang_config["conversation_language"] = existing_lang["conversation_language"]
+                        if "conversation_language_name" in existing_lang:
+                            lang_config["conversation_language_name"] = existing_lang["conversation_language_name"]
+
         # Ensure project section exists and set defaults
         if "project" not in config:
             config["project"] = {}
@@ -202,7 +250,6 @@ class PhaseExecutor:
             project_config["optimized"] = False  # Default value
 
         # Write config.json
-        config_path = project_path / ".moai" / "config.json"
         with open(config_path, "w", encoding="utf-8") as f:
             json.dump(config, f, indent=2, ensure_ascii=False)
 
@@ -216,9 +263,8 @@ class PhaseExecutor:
     ) -> None:
         """Phase 5: validation and wrap-up.
 
-        @CODE:INIT-004:PHASE5 | Phase 5 verification logic
+        @CODE:INIT-PHASE-001 | Phase 5 verification logic
         @REQ:VALIDATION-001 | SPEC-INIT-004: Verify required files after initialization completion
-        @CODE:INIT-004:PHASE5-INTEGRATION | Integration of validation in Phase 5
 
         Args:
             project_path: Project path.
@@ -230,8 +276,8 @@ class PhaseExecutor:
             "Phase 5: Validation and finalization...", progress_callback
         )
 
-        # @CODE:INIT-004:VERIFY-001 | Validate installation results
-        # @CODE:INIT-004:VALIDATION-CHECK | Comprehensive installation validation
+        # Validate installation results
+        # Comprehensive installation validation
         # Verifies all required files including 4 Alfred command files:
         # - 0-project.md, 1-plan.md, 2-run.md, 3-sync.md
         self.validator.validate_installation(project_path)
