@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# @CODE:HOOKS-CLARITY-001 | SPEC: Individual hook files for better UX
+# @CODE:HOOKS-CLARITY-CKPT | SPEC: Individual hook files for better UX
 """PreToolUse Hook: Automatic Safety Checkpoint Creation
 
 Claude Code Event: PreToolUse
@@ -17,11 +17,12 @@ Risky Operations Detected:
 
 import json
 import sys
-from pathlib import
-from utils.timeout import CrossPlatformTimeout, TimeoutError as PlatformTimeoutError
- Path
+from pathlib import Path
 from typing import Any
 
+from utils.timeout import CrossPlatformTimeout
+from utils.timeout import TimeoutError as PlatformTimeoutError
+
 # Setup import path for shared modules
 HOOKS_DIR = Path(__file__).parent
 SHARED_DIR = HOOKS_DIR / "shared"
@@ -31,10 +32,6 @@ if str(SHARED_DIR) not in sys.path:
 from handlers import handle_pre_tool_use
 
 
-    pass
-
-
-
 def main() -> None:
     """Main entry point for PreToolUse hook
 
@@ -50,7 +47,7 @@ def main() -> None:
     """
     # Set 5-second timeout
     timeout = CrossPlatformTimeout(5)
-timeout.start()
+    timeout.start()
 
     try:
         # Read JSON payload from stdin
