@@ -11,11 +11,12 @@ Output: System message with formatted project summary
 
 import json
 import sys
-from pathlib import
-from utils.timeout import CrossPlatformTimeout, TimeoutError as PlatformTimeoutError
- Path
+from pathlib import Path
 from typing import Any
 
+from utils.timeout import CrossPlatformTimeout
+from utils.timeout import TimeoutError as PlatformTimeoutError
+
 # Setup import path for shared modules
 HOOKS_DIR = Path(__file__).parent
 SHARED_DIR = HOOKS_DIR / "shared"
@@ -25,10 +26,6 @@ if str(SHARED_DIR) not in sys.path:
 from handlers import handle_session_start
 
 
-    pass
-
-
-
 def main() -> None:
     """Main entry point for SessionStart hook
 
@@ -44,7 +41,7 @@ def main() -> None:
     """
     # Set 5-second timeout
     timeout = CrossPlatformTimeout(5)
-timeout.start()
+    timeout.start()
 
     try:
         # Read JSON payload from stdin
