@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# @CODE:HOOKS-CLARITY-001 | SPEC: Individual hook files for better UX
+# @CODE:HOOKS-CLARITY-DOCS | SPEC: Individual hook files for better UX
 """UserPromptSubmit Hook: Just-In-Time Document Loading
 
 Claude Code Event: UserPromptSubmit
@@ -12,9 +12,11 @@ Output: additionalContext with document path suggestions
 import json
 import sys
 from pathlib import Path
-from utils.timeout import CrossPlatformTimeout, TimeoutError as PlatformTimeoutError
 from typing import Any
 
+from utils.timeout import CrossPlatformTimeout
+from utils.timeout import TimeoutError as PlatformTimeoutError
+
 # Setup import path for shared modules
 HOOKS_DIR = Path(__file__).parent
 SHARED_DIR = HOOKS_DIR / "shared"
@@ -24,7 +26,6 @@ if str(SHARED_DIR) not in sys.path:
 from handlers import handle_user_prompt_submit
 
 
-
 def main() -> None:
     """Main entry point for UserPromptSubmit hook
 
@@ -49,7 +50,7 @@ def main() -> None:
     """
     # Set 5-second timeout
     timeout = CrossPlatformTimeout(5)
-timeout.start()
+    timeout.start()
 
     try:
         # Read JSON payload from stdin
